@@ -14,7 +14,6 @@ specific language governing permissions and limitations
 under the License.
 """
 import calendar
-import datetime
 import datetime as dt
 import json
 import logging
@@ -30,18 +29,16 @@ from typing import Tuple, Generator, Iterable, Optional, Dict, List, Union
 import backoff
 import cachetools
 import pandas as pd
-import pytz
 from dateutil.relativedelta import relativedelta
 from pydash import get
 
-from gs_quant.api.gs.assets import GsAsset, AssetParameters, AssetType as GsAssetType, Currency, GsIdType, GsAssetApi
+from gs_quant.api.gs.assets import GsAsset, GsIdType, GsAssetApi
 from gs_quant.api.gs.data import GsDataApi
 from gs_quant.api.utils import ThreadPoolManager
 from gs_quant.base import get_enum_value
-from gs_quant.common import DateLimit
-from gs_quant.data import DataMeasure, DataFrequency, Dataset
-from gs_quant.data.coordinate import DataDimensions
-from gs_quant.data.coordinate import DateOrDatetime
+from gs_quant.common import AssetClass, AssetParameters, AssetType as GsAssetType, Currency, DateLimit
+from gs_quant.data import DataMeasure, DataFrequency, Dataset, AssetMeasure
+from gs_quant.data.coordinate import DataDimensions, DateOrDatetime
 from gs_quant.data.core import IntervalFrequency, DataAggregationOperator
 from gs_quant.entities.entity import Entity, EntityIdentifier, EntityType, PositionedEntity
 from gs_quant.errors import MqValueError, MqTypeError, MqRequestError
@@ -49,7 +46,6 @@ from gs_quant.json_encoder import JSONEncoder
 from gs_quant.markets import PricingContext
 from gs_quant.markets.indices_utils import BasketType, IndicesDatasets
 from gs_quant.session import GsSession
-from gs_quant.target.common import AssetClass
 from gs_quant.target.data import DataQuery
 
 _logger = logging.getLogger(__name__)
@@ -231,6 +227,7 @@ class SecurityIdentifier(EntityIdentifier):
     ID = "id"
     CUSIP = "cusip"
     CUSIP8 = "cusip8"
+    CINS = "cins"
     SEDOL = "sedol"
     ISIN = "isin"
     TICKER = "ticker"
@@ -241,6 +238,8 @@ class SecurityIdentifier(EntityIdentifier):
     BBG = "bbg"
     ASSET_ID = "assetId"
     ANY = "identifiers"
+    BARRA_ID = "barraId"
+    AXIOMA_ID = "axiomaId"
 
 
 class ReturnType(Enum):
@@ -388,6 +387,42 @@ class Asset(Entity, metaclass=ABCMeta):
         ids = self.get_identifiers(as_of=as_of)
         return ids.get(id_type.value)
 
+    def get_asset_measures(self) -> List[AssetMeasure]:
+        """
+        Get asset measures
+
+        :return: A list consisting of the following measures available for an asset: type, frequency, datasetField.
+        For more details check the fields defined in class: 'AssetMeasures'
+
+        **Usage**
+
+        Get list of measures available for an asset
+
+        **Examples**
+
+        >>> from gs_quant.markets.securities import SecurityMaster,AssetIdentifier
+        >>>
+        >>> asset = SecurityMaster.get_asset("USDJPY", AssetIdentifier.BLOOMBERG_ID)
+        >>> asset.get_asset_measures()
+
+        **See also**
+
+        :class:`AssetMeasures`
+
+        """
+
+        availability_response = GsSession.current._get(f'/data/measures/{self.get_marquee_id()}/availability')
+        final_measure_set = set()
+
+        if availability_response['data']:
+            for measure_set in availability_response['data']:
+                asset_measures = AssetMeasure.from_dict(measure_set)
+
+                if {'type', 'frequency', 'datasetField'} <= measure_set.keys():
+                    final_measure_set.add(asset_measures)
+
+        return list(final_measure_set)
+
     def get_data_series(self,
                         measure: DataMeasure,
                         dimensions: Optional[DataDimensions] = None,
@@ -429,6 +464,8 @@ class Asset(Entity, metaclass=ABCMeta):
         coordinate = self.get_data_coordinate(measure, dimensions, frequency)
         if coordinate is None:
             raise MqValueError(f"No data coordinate found for parameters: {measure, dimensions, frequency}")
+        elif coordinate.dataset_id is None:
+            raise MqValueError(f"Measure '{measure.value}' not found for asset: {self.__id}")
         return coordinate.get_series(start=start, end=end, dates=dates, operator=operator)
 
     def get_latest_close_price(self) -> float:
@@ -691,12 +728,12 @@ class SecMasterAsset(Asset):
         if self.__cached_identifiers is None:
             self.__load_identifiers()
 
-        if isinstance(start, datetime.datetime):
+        if isinstance(start, dt.datetime):
             start_date = start.date
         else:
             start_date = start
 
-        if isinstance(end, datetime.datetime):
+        if isinstance(end, dt.datetime):
             end_date = end.date
         else:
             end_date = end
@@ -749,14 +786,14 @@ class SecMasterAsset(Asset):
             for temporal_xref in results:
                 id_type = temporal_xref['type']
                 xref_dict = {
-                    "start_date": datetime.datetime.strptime(temporal_xref['startDate'], "%Y-%m-%d").date(),
+                    "start_date": dt.datetime.strptime(temporal_xref['startDate'], "%Y-%m-%d").date(),
                     "update_date": temporal_xref['updateTime'],
                     "value": temporal_xref['value']
                 }
                 if temporal_xref['endDate'] == "9999-99-99":
-                    xref_dict['end_date'] = datetime.datetime.max.date()
+                    xref_dict['end_date'] = dt.datetime.max.date()
                 else:
-                    xref_dict['end_date'] = datetime.datetime.strptime(temporal_xref['endDate'], "%Y-%m-%d").date()
+                    xref_dict['end_date'] = dt.datetime.strptime(temporal_xref['endDate'], "%Y-%m-%d").date()
                 xrefs[id_type].append(xref_dict)
             self.__cached_identifiers = xrefs
 
@@ -796,12 +833,12 @@ class Stock(Asset):
         if _type not in BasketType.to_list():
             raise MqValueError(f'Asset {basket_identifier} of type {_type} is not a Custom or Research Basket.')
 
-        query = DataQuery(where={'assetId': self.get_marquee_id(), 'basketId': _id},
+        query = DataQuery(where={'gsid': self.get_identifier(AssetIdentifier.GSID, end), 'basketId': _id},
                           start_date=start, end_date=end)
-        response = GsDataApi.query_data(query=query, dataset_id=IndicesDatasets.THEMATIC_FACTOR_BETAS_V1_STANDARD.value)
+        response = GsDataApi.query_data(query=query, dataset_id=IndicesDatasets.THEMATIC_FACTOR_BETAS_STANDARD.value)
         df = []
         for r in response:
-            df.append({'date': r['date'], 'assetId': r['assetId'], 'basketId': r['basketId'],
+            df.append({'date': r['date'], 'gsid': r['gsid'], 'basketId': r['basketId'],
                        'thematicBeta': r['beta']})
         df = pd.DataFrame(df)
         return df.set_index('date')
@@ -1111,7 +1148,7 @@ class FutureContract(Asset):
     def __init__(self,
                  id_: str,
                  asset_class: Union[AssetClass, str],
-                 name: Union[AssetClass, str],
+                 name: str,
                  entity: Optional[Dict] = None):
         if isinstance(asset_class, str):
             asset_class = get_enum_value(AssetClass, asset_class)
@@ -1418,7 +1455,7 @@ class SecurityMaster:
             return Fund(gs_asset.id, gs_asset.name, gs_asset.assetClass, entity=asset_entity)
 
         if asset_type == GsAssetType.Default_Swap.value:
-            return DefaultSwap(gs_asset.id, gs_asset.asset_class, entity=asset_entity)
+            return DefaultSwap(gs_asset.id, gs_asset.name, entity=asset_entity)
 
         if asset_type == GsAssetType.Swaption.value:
             return Swaption(gs_asset.id, gs_asset.name, entity=asset_entity)
@@ -1453,6 +1490,47 @@ class SecurityMaster:
     def set_source(cls, source: SecurityMasterSource):
         cls._source = source
 
+    @classmethod
+    def _get_asset_query(cls,
+                         id_value: Union[str, List[str]],
+                         id_type: Union[AssetIdentifier, SecurityIdentifier],
+                         as_of: Union[dt.date, dt.datetime] = None,
+                         exchange_code: ExchangeCode = None,
+                         asset_type: AssetType = None) -> Tuple[Dict, dt.datetime]:
+        if not as_of:
+            current = PricingContext.current
+            if not current.is_entered:
+                with current:
+                    as_of = current.pricing_date
+            else:
+                as_of = current.pricing_date
+        if isinstance(as_of, dt.date):
+            as_of = dt.datetime.combine(as_of, dt.time(0, 0), dt.timezone.utc)
+        query = {"id" if id_type == AssetIdentifier.MARQUEE_ID else id_type.value.lower(): id_value}
+        if exchange_code is not None:
+            query['exchange'] = exchange_code.value
+        if asset_type is not None:
+            query['type'] = [t.value for t in cls.__asset_type_to_gs_types(asset_type)]
+        return query, as_of
+
+    @classmethod
+    def _get_asset_results(cls, results, sort_by_rank) -> Asset:
+        if sort_by_rank:
+            result = get(results, '0')
+            if result:
+                result = GsAsset.from_dict(result)
+        else:
+            result = next(iter(results), None)
+        if result:
+            return cls.__gs_asset_to_asset(result)
+        return None
+
+    @classmethod
+    def _get_many_assets_results(cls, results) -> List[Asset]:
+        if results is not None:
+            return [cls.__gs_asset_to_asset(result) for result in results]
+        return []
+
     @classmethod
     def get_asset(cls,
                   id_value: str,
@@ -1506,49 +1584,194 @@ class SecurityMaster:
                 raise NotImplementedError('argument not implemented for Security Master (supported in Asset Service)')
             return cls._get_security_master_asset(id_value, id_type, as_of=as_of, fields=fields)
 
-        if not as_of:
-            current = PricingContext.current
-            if not current.is_entered:
-                with current:
-                    as_of = current.pricing_date
-            else:
-                as_of = current.pricing_date
-
-        if isinstance(as_of, dt.date):
-            as_of = dt.datetime.combine(as_of, dt.time(0, 0), pytz.utc)
-
         if id_type is AssetIdentifier.MARQUEE_ID:
             gs_asset = GsAssetApi.get_asset(id_value)
             return cls.__gs_asset_to_asset(gs_asset)
 
-        query = {id_type.value.lower(): id_value}
-
-        if exchange_code is not None:
-            query['exchange'] = exchange_code.value
-
-        if asset_type is not None:
-            query['type'] = [t.value for t in cls.__asset_type_to_gs_types(asset_type)]
-
+        query, as_of = cls._get_asset_query(id_value, id_type, as_of, exchange_code, asset_type)
         if sort_by_rank:
             results = GsAssetApi.get_many_assets(as_of=as_of, return_type=dict, order_by=['>rank'], **query)
-            result = get(results, '0')
-
-            if result:
-                result = GsAsset.from_dict(result)
+            return cls._get_asset_results(results, sort_by_rank)
         else:
             results = GsAssetApi.get_many_assets(as_of=as_of, **query)
-            result = next(iter(results), None)
-
-        if result:
-            return cls.__gs_asset_to_asset(result)
+            return cls._get_asset_results(results, sort_by_rank)
 
     @classmethod
-    def _get_security_master_asset(cls,
-                                   id_value: str,
-                                   id_type: SecurityIdentifier,
-                                   as_of: Union[dt.date, dt.datetime] = None,
-                                   fields: Optional[List[str]] = None) -> SecMasterAsset:
-        as_of = as_of or datetime.datetime(2100, 1, 1)
+    async def get_asset_async(cls,
+                              id_value: str,
+                              id_type: Union[AssetIdentifier, SecurityIdentifier],
+                              as_of: Union[dt.date, dt.datetime] = None,
+                              exchange_code: ExchangeCode = None,
+                              asset_type: AssetType = None,
+                              sort_by_rank: bool = True,
+                              fields: Optional[List[str]] = None) -> Asset:
+        """
+        Get an asset by identifier and identifier type
+
+        :param id_value: identifier value
+        :param id_type: identifier type
+        :param exchange_code: exchange code
+        :param asset_type: asset type
+        :param as_of: As of date for query
+        :param sort_by_rank: whether to sort assets by rank. This flag is ignored when using SecMasterContext
+        :param fields: asset fields to return
+        :return: Asset object or None
+
+        **Usage**
+
+        Get asset object using a specified identifier and identifier type. Where the identifiers are temporal (and can
+        change over time), will use the current MarketContext to evaluate based on the specified date.
+
+        **Examples**
+
+        Get asset by bloomberg id:
+
+        >>> gs = await SecurityMaster.get_asset_async("GS UN", AssetIdentifier.BLOOMBERG_ID)
+
+        Get asset by ticker and exchange code:
+
+        >>> gs = await SecurityMaster.get_asset_async("GS", AssetIdentifier.TICKER, exchange_code=ExchangeCode.NYSE)
+
+        Get asset by ticker and asset type:
+
+        >>> spx = await SecurityMaster.get_asset_async("SPX", AssetIdentifier.TICKER, asset_type=AssetType.INDEX)
+
+        **See also**
+
+        :class:`AssetIdentifier`
+        :func:`get_many_assets`
+
+        """
+        if cls._source == SecurityMasterSource.SECURITY_MASTER:
+            if not isinstance(id_type, SecurityIdentifier):
+                raise MqTypeError('expected a security identifier')
+            if exchange_code or asset_type:
+                raise NotImplementedError('argument not implemented for Security Master (supported in Asset Service)')
+            return await cls._get_security_master_asset_async(id_value, id_type, as_of=as_of, fields=fields)
+
+        if id_type is AssetIdentifier.MARQUEE_ID:
+            gs_asset = await GsAssetApi.get_asset_async(id_value)
+            return cls.__gs_asset_to_asset(gs_asset)
+
+        query, as_of = cls._get_asset_query(id_value, id_type, as_of, exchange_code, asset_type)
+        if sort_by_rank:
+            results = await GsAssetApi.get_many_assets_async(as_of=as_of, return_type=dict, order_by=['>rank'], **query)
+            return cls._get_asset_results(results, sort_by_rank)
+        else:
+            results = await GsAssetApi.get_many_assets_async(as_of=as_of, **query)
+            return cls._get_asset_results(results, sort_by_rank)
+
+    @classmethod
+    def get_many_assets(cls,
+                        id_values: List[str],
+                        id_type: AssetIdentifier,
+                        limit: int = 100,
+                        as_of: Union[dt.date, dt.datetime] = None,
+                        exchange_code: ExchangeCode = None,
+                        sort_by_rank: bool = True) -> List[Asset]:
+        """
+        Get an asset by identifier and identifier type
+
+        :param id_values: identifier values
+        :param id_type: identifiers type
+        :param limit: max number of results
+        :param exchange_code: exchange code
+        :param as_of: As of date for query
+        :param sort_by_rank: whether to sort assets by rank. This flag is ignored when using SecMasterContext
+        :return: list of Asset objects or None
+
+        **Usage**
+
+        Get asset object using a specified identifier and identifier type. Where the identifiers are temporal (and can
+        change over time), will use the current MarketContext to evaluate based on the specified date.
+
+        **Examples**
+
+        Get asset by bloomberg id:
+
+        >>> gs = SecurityMaster.get_many_assets(["GS UN", "MSFT UW"], AssetIdentifier.BLOOMBERG_ID)
+
+        Get asset by ticker and exchange code:
+
+        >>> gs = SecurityMaster.get_many_assets(["GS", "MSFT"], AssetIdentifier.TICKER, exchange_code=ExchangeCode.NYSE)
+
+        Get asset by ticker and asset type:
+
+        >>> spx = SecurityMaster.get_many_assets(["SPX"], AssetIdentifier.TICKER, asset_type=AssetType.INDEX)
+
+        **See also**
+
+        :class:`AssetIdentifier`
+        :func:`get_many_assets`
+
+        """
+        query, as_of = cls._get_asset_query(id_values, id_type, as_of, exchange_code)
+        if sort_by_rank:
+            results = GsAssetApi.get_many_assets(as_of=as_of, order_by=['>rank'], limit=limit, **query)
+        else:
+            results = GsAssetApi.get_many_assets(as_of=as_of, limit=limit, **query)
+        return cls._get_many_assets_results(results)
+
+    @classmethod
+    async def get_many_assets_async(cls,
+                                    id_values: List[str],
+                                    id_type: AssetIdentifier,
+                                    limit: int = 100,
+                                    as_of: Union[dt.date, dt.datetime] = None,
+                                    exchange_code: ExchangeCode = None,
+                                    sort_by_rank: bool = True) -> List[Asset]:
+        """
+        Get an asset by identifier and identifier type
+
+        :param id_values: identifier values
+        :param id_type: identifiers type
+        :param limit: max number of results
+        :param exchange_code: exchange code
+        :param as_of: As of date for query
+        :param sort_by_rank: whether to sort assets by rank. This flag is ignored when using SecMasterContext
+        :return: list of Asset objects or None
+
+        **Usage**
+
+        Get asset object using a specified identifier and identifier type. Where the identifiers are temporal (and can
+        change over time), will use the current MarketContext to evaluate based on the specified date.
+
+        **Examples**
+
+        Get asset by bloomberg id:
+
+        >>> gs = await SecurityMaster.get_many_assets_async(["GS UN"], AssetIdentifier.BLOOMBERG_ID)
+
+        Get asset by ticker and exchange code:
+
+        >>> gs = await SecurityMaster.get_many_assets_async(["GS"], AssetIdentifier.TICKER,
+        >>>                                                 exchange_code=ExchangeCode.NYSE)
+
+        Get asset by ticker and asset type:
+
+        >>> spx = await SecurityMaster.get_many_assets_async(["SPX"], AssetIdentifier.TICKER,
+        >>>                                                  asset_type=AssetType.INDEX)
+
+        **See also**
+
+        :class:`AssetIdentifier`
+        :func:`get_many_assets`
+
+        """
+        query, as_of = cls._get_asset_query(id_values, id_type, as_of, exchange_code)
+        if sort_by_rank:
+            results = await GsAssetApi.get_many_assets_async(as_of=as_of, order_by=['>rank'], limit=limit, **query)
+        else:
+            results = await GsAssetApi.get_many_assets_async(as_of=as_of, limit=limit, **query)
+        return cls._get_many_assets_results(results)
+
+    @classmethod
+    def _get_security_master_asset_params(cls,
+                                          id_value: str,
+                                          id_type: SecurityIdentifier,
+                                          as_of: Union[dt.date, dt.datetime] = None,
+                                          fields: Optional[List[str]] = None) -> dict:
+        as_of = as_of or dt.datetime(2100, 1, 1)
         type_ = id_type.value
         params = {
             type_: id_value,
@@ -1565,11 +1788,13 @@ class SecurityMaster:
             }
             request_fields.update(fields)
             params['fields'] = request_fields
+        return params
 
-        r = GsSession.current._get('/markets/securities', payload=params)
-        if r['totalResults'] == 0:
+    @classmethod
+    def _get_security_master_asset_response(cls, response) -> SecMasterAsset:
+        if response['totalResults'] == 0:
             return None
-        asset_dict = r['results'][0]
+        asset_dict = response['results'][0]
         asset_id = asset_dict['identifiers'].get("assetId", None)
         # Converting dict to Asset Class
         asset_name = asset_dict.get('name', None)
@@ -1590,8 +1815,28 @@ class SecurityMaster:
                                       f"AssetClass={asset_dict['assetClass']}.")
 
     @classmethod
-    def get_identifiers(cls, id_values: List[str], id_type: SecurityIdentifier, as_of: datetime.datetime = None,
-                        start: datetime.datetime = None, end: datetime.datetime = None) -> dict:
+    def _get_security_master_asset(cls,
+                                   id_value: str,
+                                   id_type: SecurityIdentifier,
+                                   as_of: Union[dt.date, dt.datetime] = None,
+                                   fields: Optional[List[str]] = None) -> SecMasterAsset:
+        params = cls._get_security_master_asset_params(id_value, id_type, as_of, fields)
+        response = GsSession.current._get('/markets/securities', payload=params)
+        return cls._get_security_master_asset_response(response)
+
+    @classmethod
+    async def _get_security_master_asset_async(cls,
+                                               id_value: str,
+                                               id_type: SecurityIdentifier,
+                                               as_of: Union[dt.date, dt.datetime] = None,
+                                               fields: Optional[List[str]] = None) -> SecMasterAsset:
+        params = cls._get_security_master_asset_params(id_value, id_type, as_of, fields)
+        response = await GsSession.current._get_async('/markets/securities', payload=params)
+        return cls._get_security_master_asset_response(response)
+
+    @classmethod
+    def get_identifiers(cls, id_values: List[str], id_type: SecurityIdentifier, as_of: dt.datetime = None,
+                        start: dt.datetime = None, end: dt.datetime = None) -> dict:
         """
         Get identifiers for given assets.
 
@@ -1605,9 +1850,9 @@ class SecurityMaster:
         if cls._source != SecurityMasterSource.SECURITY_MASTER:
             raise NotImplementedError("method not available when using Asset Service")
 
-        as_of = as_of or datetime.datetime.now()
-        start = start or datetime.datetime(1970, 1, 1)
-        end = end or datetime.datetime(2100, 1, 1)
+        as_of = as_of or dt.datetime.now()
+        start = start or dt.datetime(1970, 1, 1)
+        end = end or dt.datetime(2100, 1, 1)
 
         type_ = id_type.value
         params = {
@@ -1632,7 +1877,7 @@ class SecurityMaster:
                 time_str = e['updateTime'].split('.')[0]
                 if time_str.endswith('Z'):
                     time_str = time_str[0:-1]
-                time = datetime.datetime.strptime(time_str, '%Y-%m-%dT%H:%M:%S')
+                time = dt.datetime.strptime(time_str, '%Y-%m-%dT%H:%M:%S')
                 if start <= time <= end:
                     piece.append(e)
             output[k] = piece
@@ -1649,7 +1894,7 @@ class SecurityMaster:
 
     @classmethod
     def get_all_identifiers_gen(cls, class_: AssetClass = None, types: Optional[List[AssetType]] = None,
-                                as_of: datetime.datetime = None, *, id_type: SecurityIdentifier = SecurityIdentifier.ID,
+                                as_of: dt.datetime = None, *, id_type: SecurityIdentifier = SecurityIdentifier.ID,
                                 use_offset_key=True, sleep=0.5) -> Generator[dict, None, None]:
         """
         Get identifiers for all matching assets. Returns a generator iterator so that the caller can load each page of
@@ -1666,7 +1911,7 @@ class SecurityMaster:
         if cls._source != SecurityMasterSource.SECURITY_MASTER:
             raise NotImplementedError("method not available when using Asset Service")
 
-        as_of = as_of or datetime.datetime.now()
+        as_of = as_of or dt.datetime.now()
         if types is not None:
             p = partial(cls.asset_type_to_str, class_)
             types = set(map(p, types))
@@ -1710,7 +1955,7 @@ class SecurityMaster:
 
     @classmethod
     def get_all_identifiers(cls, class_: AssetClass = None, types: Optional[List[AssetType]] = None,
-                            as_of: datetime.datetime = None, *, id_type: SecurityIdentifier = SecurityIdentifier.ID,
+                            as_of: dt.datetime = None, *, id_type: SecurityIdentifier = SecurityIdentifier.ID,
                             use_offset_key=True, sleep=0.5) -> Dict[str, dict]:
         """
         Get identifiers for all matching assets.
@@ -1738,10 +1983,10 @@ class SecurityMaster:
             input_type: SecurityIdentifier,
             ids: Iterable[str],
             output_types: Iterable[SecurityIdentifier] = frozenset([SecurityIdentifier.GSID]),
-            start_date: datetime.date = None,
-            end_date: datetime.date = None,
-            as_of_date: datetime.date = None
-    ) -> Dict[datetime.date, dict]:
+            start_date: dt.date = None,
+            end_date: dt.date = None,
+            as_of_date: dt.date = None
+    ) -> Dict[dt.date, dict]:
         """
         Map to other identifier types, from given IDs.
 
@@ -1760,7 +2005,7 @@ class SecurityMaster:
 
         Get Bloomberg ticker for 104563 as-of a past date:
         >>> result = SecurityMaster.map_identifiers(SecurityIdentifier.GSID, ["104563"], [SecurityIdentifier.BBG],
-        ...                                         as_of_date=datetime.date(2021, 4, 19))
+        ...                                         as_of_date=dt.date(2021, 4, 19))
         """
         if isinstance(ids, str):
             raise MqTypeError("expected an iterable of strings e.g. list of strings")
@@ -1778,12 +2023,12 @@ class SecurityMaster:
             if (start_date or end_date) is not None:
                 raise MqValueError('use as_of_date instead of start_date and/or end_date')
             if as_of_date is None:
-                as_of_date = datetime.date.today()
+                as_of_date = dt.date.today()
 
             input_type = get_asset_id_type(input_type)
             output_type = get_asset_id_type(output_types[0])
-            as_of = None if as_of_date is None else datetime.datetime.combine(as_of_date,
-                                                                              datetime.time(tzinfo=pytz.UTC))
+            as_of = None if as_of_date is None else dt.datetime.combine(as_of_date,
+                                                                        dt.time(tzinfo=dt.timezone.utc))
             result = GsAssetApi.map_identifiers(input_type, output_type, list(ids), as_of=as_of, multimap=True)
             if len(result) == 0:
                 return result
@@ -1814,10 +2059,10 @@ class SecurityMaster:
 
         output = dict()
         date_format = '%Y-%m-%d'
-        date_delta = datetime.timedelta(days=1)
+        date_delta = dt.timedelta(days=1)
         for row in results:
-            current = datetime.datetime.strptime(row['startDate'], date_format)
-            end = datetime.datetime.strptime(row['endDate'], date_format)
+            current = dt.datetime.strptime(row['startDate'], date_format)
+            end = dt.datetime.strptime(row['endDate'], date_format)
             while current <= end:
                 outer = output.setdefault(current, dict())
                 inner = outer.setdefault(row["input"], dict())
