@@ -27,12 +27,15 @@ import gs_quant.timeseries.measures_fx_vol as tm_fxo
 import gs_quant.timeseries.measures_xccy as tm
 from gs_quant.api.gs.assets import GsAsset
 from gs_quant.api.gs.data import GsDataApi, MarketDataResponseFrame, QueryType
+from gs_quant.common import PricingLocation
 from gs_quant.errors import MqError, MqValueError
+from gs_quant.markets import PricingContext
+from gs_quant.markets.securities import Bond, Cross, Currency
 from gs_quant.session import GsSession, Environment
-from gs_quant.target.common import PricingLocation
 from gs_quant.test.timeseries.utils import mock_request
-from gs_quant.timeseries import Currency, Cross, Bond, CurrencyEnum, SecurityMaster
+from gs_quant.timeseries import Currency as CurrencyEnum, SecurityMaster
 from gs_quant.timeseries.measures_fx_vol import _currencypair_to_tdapi_fxo_asset, _currencypair_to_tdapi_fxfwd_asset
+from gs_quant.timeseries.measures_helper import VolReference
 
 _index = [pd.Timestamp('2021-03-30')]
 _test_datasets = ('TEST_DATASET',)
@@ -40,7 +43,13 @@ _test_datasets = ('TEST_DATASET',)
 
 def test_currencypair_to_tdapi_fxfwd_asset():
     mock_eur = Cross('MA8RY265Q34P7TWZ', 'EURUSD')
+    replace = Replacer()
+    xrefs = replace('gs_quant.timeseries.measures_fx_vol._get_tdapi_fxo_assets', Mock())
+    xrefs.return_value = 'MA8RY265Q34P7TWZ'
+    bbid_mock = replace('gs_quant.timeseries.measures_fx_vol.Asset.get_identifier', Mock())
+    bbid_mock.return_value = {'EURUSD'}
     assert _currencypair_to_tdapi_fxfwd_asset(mock_eur) == "MA8RY265Q34P7TWZ"
+    replace.restore()
 
 
 def test_currencypair_to_tdapi_fxo_asset(mocker):
@@ -51,7 +60,7 @@ def test_currencypair_to_tdapi_fxo_asset(mocker):
     mocker.patch.object(SecurityMaster, 'get_asset', side_effect=mock_request)
     bbid_mock = replace('gs_quant.timeseries.measures_fx_vol.Asset.get_identifier', Mock())
 
-    with tm_rates.PricingContext(dt.date.today()):
+    with PricingContext(dt.date.today()):
         cur = [
             {
                 "currency_assetId": "MAK1FHKH5P5GJSHH",
@@ -153,7 +162,9 @@ def test_get_tdapi_fxo_assets():
     replace = Replacer()
     assets = replace('gs_quant.timeseries.measures.GsAssetApi.get_many_assets', Mock())
     assets.return_value = [mock_asset_1]
-    assert 'MAW8SAXPSKYA94E2' == tm_fxo._get_tdapi_fxo_assets()
+    kwargs = dict(asset_parameters_expiration_date='5y', asset_parameters_call_currency='USD',
+                  asset_parameters_put_currency='EUR')
+    assert 'MAW8SAXPSKYA94E2' == tm_fxo._get_tdapi_fxo_assets(**kwargs)
     replace.restore()
 
     assets = replace('gs_quant.timeseries.measures.GsAssetApi.get_many_assets', Mock())
@@ -199,7 +210,8 @@ def test_get_tdapi_fxo_assets():
 def mock_curr(_cls, _q):
     d = {
         'impliedVolatility': [1, 2, 3],
-        'fwdPoints': [4, 5, 6]
+        'fwdPoints': [4, 5, 6],
+        'forwardPoint': [7, 8, 9]
     }
     df = MarketDataResponseFrame(data=d, index=_index * 3)
     df.dataset_ids = _test_datasets
@@ -295,8 +307,16 @@ def test_fwd_points(mocker):
     args['settlement_date'] = '6m'
 
     args['real_time'] = True
-    with pytest.raises(NotImplementedError):
-        tm_fxo.fwd_points(**args)
+    xrefs = replace('gs_quant.timeseries.measures.Asset.get_identifier', Mock())
+    xrefs.return_value = 'EURUSD'
+    identifiers = replace('gs_quant.timeseries.measures_fx_vol._get_tdapi_fxo_assets', Mock())
+    identifiers.return_value = {'MAGZMXVM0J282ZTR'}
+    mocker.patch.object(GsDataApi, 'get_market_data', return_value=mock_curr(None, None))
+    actual = tm_fxo.fwd_points(**args)
+    expected = tm.ExtendedSeries([7, 8, 9], index=_index * 3, name='forwardPoint')
+    expected.dataset_ids = _test_datasets
+    assert_series_equal(expected, actual)
+    assert actual.dataset_ids == _test_datasets
     args['real_time'] = False
 
     args['asset'] = Cross('MAGZMXVM0J282ZTR', 'EURUSD')
@@ -326,79 +346,6 @@ def test_fwd_points(mocker):
     replace.restore()
 
 
-def test_fx_vol_measure_legacy(mocker):
-    replace = Replacer()
-    args = dict(tenor='1m', strike_reference=tm_fxo.VolReference('delta_neutral'), relative_strike=0,
-                location=None, legacy_implementation=True)
-
-    mock_gbp = Cross('MA26QSMPX9990G66', 'GBPUSD')
-    args['asset'] = mock_gbp
-    expected = tm.ExtendedSeries([1, 2, 3], index=_index * 3, name='impliedVolatility')
-    expected.dataset_ids = _test_datasets
-    mocker.patch.object(tm_rates, 'get_historical_and_last_for_measure',
-                        return_value=expected)
-    mocker.patch.object(tm_rates, '_extract_series_from_df',
-                        return_value=expected)
-    xrefs = replace('gs_quant.timeseries.measures.cross_stored_direction_for_fx_vol', Mock())
-    xrefs.return_value = 'MA26QSMPX9990G66'
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-    replace.restore()
-
-    args['legacy_implementation'] = False
-    xrefs = replace('gs_quant.timeseries.measures.Asset.get_identifier', Mock())
-    xrefs.return_value = None
-    with pytest.raises(MqValueError):
-        tm_fxo.implied_volatility_fxvol(**args)
-
-    xrefs = replace('gs_quant.timeseries.measures.Asset.get_identifier', Mock())
-    xrefs.return_value = 'GBPUSD'
-    xrefs = replace('gs_quant.timeseries.measures._cross_stored_direction_helper', Mock())
-    xrefs.return_value = 'GBPUSD'
-    mocker.patch.object(tm_fxo, 'implied_volatility_new',
-                        return_value=expected)
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-
-    xrefs = replace('gs_quant.timeseries.measures.Asset.get_identifier', Mock())
-    xrefs.return_value = 'USDUSD'
-    xrefs = replace('gs_quant.timeseries.measures_fx_vol._cross_stored_direction_helper', Mock())
-    xrefs.return_value = 'GBPUSD'
-    assets = replace('gs_quant.markets.securities.SecurityMaster.get_asset', Mock())
-    assets.return_value = mock_gbp
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-
-    args['strike_reference'] = tm_fxo.VolReference('delta_call')
-    args['relative_strike'] = 25
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-
-    args['strike_reference'] = tm_fxo.VolReference('delta_put')
-    args['relative_strike'] = 25
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-
-    args['strike_reference'] = tm_fxo.VolReference('spot')
-    args['relative_strike'] = 100
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-
-    args['strike_reference'] = tm_fxo.VolReference('forward')
-    args['relative_strike'] = 100
-    actual = tm_fxo.implied_volatility_fxvol(**args)
-    assert_series_equal(expected, actual)
-
-    args['strike_reference'] = tm_fxo.VolReference('normalized')
-    args['relative_strike'] = 100
-    xrefs = replace('gs_quant.timeseries.measures_fx_vol._preprocess_implied_vol_strikes_fx', Mock())
-    xrefs.return_value = ['normalized', 0]
-    with pytest.raises(MqValueError):
-        tm_fxo.implied_volatility_fxvol(**args)
-
-    replace.restore()
-
-
 def mock_df():
     d = {
         'strikeVol': [5, 1, 2],
@@ -505,5 +452,83 @@ def test_vol_swap_strike():
     replace.restore()
 
 
+def test_implied_volatility_fxvol(mocker):
+    replace = Replacer()
+
+    args = dict(tenor="1y", location=None)
+    mock_eur = Cross('MAGZMXVM0J282ZTR', 'EURUSD')
+    args['asset'] = mock_eur
+
+    xrefs = replace('gs_quant.timeseries.measures.Asset.get_identifier', Mock())
+    xrefs.return_value = 'EURUSD'
+    xrefs = replace('gs_quant.timeseries.measures_fx_vol._cross_stored_direction_helper', Mock())
+    xrefs.return_value = 'GBPUSD'
+    assets = replace('gs_quant.markets.securities.SecurityMaster.get_asset', Mock())
+    assets.return_value = mock_eur
+
+    preprocess_impl_vol = replace('gs_quant.timeseries.measures_fx_vol._preprocess_implied_vol_strikes_fx', Mock())
+    replace('gs_quant.timeseries.measures_fx_vol._get_tdapi_fxo_assets', Mock())
+    mocker.patch.object(GsDataApi, 'get_market_data', return_value=mock_curr(None, None))
+    expected = tm.ExtendedSeries([1, 2, 3], index=_index * 3, name='impliedVolatility')
+
+    args['strike_reference'] = VolReference.DELTA_CALL
+    args['relative_strike'] = 50
+    preprocess_impl_vol.return_value = ['abc', 50]
+    with pytest.raises(MqValueError):
+        tm_fxo.implied_volatility_fxvol(**args)
+
+    args['strike_reference'] = VolReference.DELTA_CALL
+    args['relative_strike'] = 50
+    preprocess_impl_vol.return_value = ['delta', 50]
+    actual = tm_fxo.implied_volatility_fxvol(**args)
+    assert_series_equal(expected, actual)
+
+    args['strike_reference'] = VolReference.DELTA_PUT
+    args['relative_strike'] = 25
+    preprocess_impl_vol.return_value = ['delta', -25]
+    actual = tm_fxo.implied_volatility_fxvol(**args)
+    assert_series_equal(expected, actual)
+
+    args['strike_reference'] = VolReference.DELTA_CALL
+    args['relative_strike'] = 0
+    preprocess_impl_vol.return_value = ['delta', 0]
+    actual = tm_fxo.implied_volatility_fxvol(**args)
+    assert_series_equal(expected, actual)
+
+    args['strike_reference'] = VolReference.SPOT
+    args['relative_strike'] = 100
+    preprocess_impl_vol.return_value = ['spot', 100]
+    actual = tm_fxo.implied_volatility_fxvol(**args)
+    assert_series_equal(expected, actual)
+
+    args['strike_reference'] = VolReference.FORWARD
+    args['relative_strike'] = 100
+    preprocess_impl_vol.return_value = ['forward', 100]
+    actual = tm_fxo.implied_volatility_fxvol(**args)
+    assert_series_equal(expected, actual)
+
+    args['strike_reference'] = VolReference.NORMALIZED
+    args['relative_strike'] = 100
+    preprocess_impl_vol = replace('gs_quant.timeseries.measures_fx_vol._preprocess_implied_vol_strikes_fx', Mock())
+    preprocess_impl_vol.return_value = ['normalized', 0]
+    with pytest.raises(MqValueError):
+        tm_fxo.implied_volatility_fxvol(**args)
+
+    xrefs = replace('gs_quant.timeseries.measures_fx_vol._cross_stored_direction_helper', Mock())
+    xrefs.return_value = 'EURUSD'
+    args['strike_reference'] = VolReference.DELTA_CALL
+    args['relative_strike'] = 50
+    preprocess_impl_vol.return_value = ['delta', 50]
+    actual = tm_fxo.implied_volatility_fxvol(**args)
+    assert_series_equal(expected, actual)
+
+    xrefs = replace('gs_quant.timeseries.measures.Asset.get_identifier', Mock())
+    xrefs.return_value = None
+    with pytest.raises(MqValueError):
+        tm_fxo.implied_volatility_fxvol(**args)
+
+    replace.restore()
+
+
 if __name__ == '__main__':
     pytest.main(args=["test_measures_fx_vol.py"])
